@@ -1,15 +1,16 @@
 package common_test
 
 import (
-	"knative.dev/serving-operator/pkg/apis/serving/v1alpha1"
 	"os"
 	"testing"
 
+	"knative.dev/operator/pkg/apis/operator/v1alpha1"
+
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
 	configv1 "github.com/openshift/api/config/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes/scheme"
-	eventingv1alpha1 "knative.dev/eventing-operator/pkg/apis/eventing/v1alpha1"
+	eventingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 )
 
@@ -19,7 +20,8 @@ func init() {
 
 func TestMutateEventing(t *testing.T) {
 	const (
-		image = "docker.io/foo:tag"
+		image1 = "docker.io/foo:tag"
+		image2 = "docker.io/baz:tag"
 	)
 	client := fake.NewFakeClient()
 	ke := &eventingv1alpha1.KnativeEventing{
@@ -29,10 +31,14 @@ func TestMutateEventing(t *testing.T) {
 		},
 	}
 	// Setup image override
-	os.Setenv("IMAGE_foo", image)
+	os.Setenv("IMAGE_foo", image1)
+	// Setup image override with deployment name
+	os.Setenv("IMAGE_bar__baz", image2)
+
 	// Mutate for OpenShift
 	if err := common.MutateEventing(ke, client); err != nil {
 		t.Error(err)
 	}
-	verifyImageOverride(t, (*v1alpha1.Registry)(&ke.Spec.Registry), "foo", image)
+	verifyImageOverride(t, (*v1alpha1.Registry)(&ke.Spec.Registry), "foo", image1)
+	verifyImageOverride(t, (*v1alpha1.Registry)(&ke.Spec.Registry), "bar/baz", image2)
 }
