@@ -7,22 +7,18 @@ import (
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/consoleclidownload"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/dashboard"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/kourier"
 	consolev1 "github.com/openshift/api/console/v1"
-	"github.com/operator-framework/operator-sdk/pkg/predicate"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/api/meta"
-	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/apimachinery/pkg/selection"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/sets"
-	"knative.dev/pkg/apis/istio/v1alpha3"
-	servingv1alpha1 "knative.dev/serving-operator/pkg/apis/serving/v1alpha1"
+	servingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller"
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
@@ -33,7 +29,6 @@ import (
 )
 
 const (
-	routeLabelKey     = "serving.knative.dev/route"
 	ingressClassKey   = "networking.knative.dev/ingress.class"
 	istioIngressClass = "istio.ingress.networking.knative.dev"
 
@@ -76,7 +71,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for changes to primary resource KnativeServing
-	err = c.Watch(&source.Kind{Type: &servingv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{}, predicate.GenerationChangedPredicate{})
+	err = c.Watch(&source.Kind{Type: &servingv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{})
 	if err != nil {
 		return err
 	}
@@ -197,8 +192,8 @@ func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *servingv1alp
 		r.ensureCustomCertsConfigMap,
 		r.installKnConsoleCLIDownload,
 		r.installKourier,
+		r.installDashboard,
 		r.ensureProxySettings,
-		r.deleteVirtualService,
 	}
 	for _, stage := range stages {
 		if err := stage(instance); err != nil {
@@ -214,7 +209,7 @@ func (r *ReconcileKnativeServing) configure(instance *servingv1alpha1.KnativeSer
 	if err := common.Mutate(instance, r.client); err != nil {
 		return err
 	}
-	if equality.Semantic.DeepEqual(before, instance) {
+	if equality.Semantic.DeepEqual(before.Spec, instance.Spec) {
 		return nil
 	}
 
@@ -226,35 +221,6 @@ func (r *ReconcileKnativeServing) configure(instance *servingv1alpha1.KnativeSer
 	return nil
 }
 
-// deleteVirtualService removes obsoleted VirtualServices.
-func (r *ReconcileKnativeServing) deleteVirtualService(instance *servingv1alpha1.KnativeServing) error {
-	labelSelector := labels.NewSelector()
-	req, err := labels.NewRequirement(routeLabelKey, selection.Exists, nil)
-	if err != nil {
-		return fmt.Errorf("failed to create requirement for label: %w", err)
-	}
-	listOpts := &client.ListOptions{LabelSelector: labelSelector.Add(*req)}
-	list := &v1alpha3.VirtualServiceList{}
-	ctx := context.TODO()
-	if err := r.client.List(ctx, listOpts, list); err != nil {
-		if meta.IsNoMatchError(err) {
-			// VirtualService CRD is not installed.
-			return nil
-		}
-		return err
-	}
-	for i := range list.Items {
-		vs := &list.Items[i]
-		if vs.GetAnnotations()[ingressClassKey] == istioIngressClass {
-			log.Info(fmt.Sprintf("deleting VirtualService %s/%s", vs.GetNamespace(), vs.GetName()))
-			if err := r.client.Delete(ctx, vs); err != nil {
-				return fmt.Errorf("failed to delete VirtualService %s/%s: %w", vs.GetNamespace(), vs.GetName(), err)
-			}
-		}
-	}
-	return nil
-}
-
 // ensureProxySettings updates the proxy settings on the KnativeServing controller.
 func (r *ReconcileKnativeServing) ensureProxySettings(instance *servingv1alpha1.KnativeServing) error {
 	proxyEnv := map[string]string{
@@ -395,8 +361,8 @@ func (r *ReconcileKnativeServing) reconcileConfigMap(instance *servingv1alpha1.K
 // Install Kourier Ingress Gateway
 func (r *ReconcileKnativeServing) installKourier(instance *servingv1alpha1.KnativeServing) error {
 	// install Kourier
-	instance.Status.MarkDependencyInstalling("Kourier")
 	if err := kourier.Apply(instance, r.client, r.scheme); err != nil {
+		instance.Status.MarkDependencyInstalling("Kourier")
 		return err
 	}
 	instance.Status.MarkDependenciesInstalled()
@@ -408,6 +374,11 @@ func (r *ReconcileKnativeServing) installKnConsoleCLIDownload(instance *servingv
 	return consoleclidownload.Apply(instance, r.client, r.scheme)
 }
 
+// installDashboard installs daashboard for OpenShift webconsole
+func (r *ReconcileKnativeServing) installDashboard(instance *servingv1alpha1.KnativeServing) error {
+	return dashboard.Apply(instance, r.client)
+}
+
 // general clean-up, mostly resources in different namespaces from servingv1alpha1.KnativeServing.
 func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServing) error {
 	finalizers := sets.NewString(instance.GetFinalizers()...)
@@ -428,6 +399,11 @@ func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServin
 		return fmt.Errorf("failed to delete kn ConsoleCLIDownload: %w", err)
 	}
 
+	log.Info("Deleting dashboard")
+	if err := dashboard.Delete(instance, r.client); err != nil {
+		return fmt.Errorf("failed to delete dashboard configmap: %w", err)
+	}
+
 	// The above might take a while, so we refetch the resource again in case it has changed.
 	refetched := &servingv1alpha1.KnativeServing{}
 	if err := r.client.Get(context.TODO(), types.NamespacedName{Namespace: instance.Namespace, Name: instance.Name}, refetched); err != nil {
